@@ -1,10 +1,10 @@
 package Net::DNS::RR::ISDN;
 
 #
-# $Id: ISDN.pm 1362 2015-06-23 08:47:14Z willem $
+# $Id: ISDN.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1362 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -22,7 +22,7 @@ use integer;
 use Net::DNS::Text;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -31,7 +31,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless defined $self->{address};
@@ -39,7 +39,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $address = $self->{address} || return '';
@@ -47,7 +47,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->address(shift);
@@ -55,7 +55,7 @@ sub parse_rdata {			## populate RR from rdata in argument list
 }
 
 
-sub defaults() {			## specify RR attribute default values
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
 	$self->sa('');
@@ -104,6 +104,9 @@ structures is discouraged and could result in program termination or
 other unpredictable behaviour.
 
 
+=head2 ISDNaddress
+
+
 =head2 address
 
     $address = $rr->address;
