@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3PARAM;
 
 #
-# $Id: NSEC3PARAM.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: NSEC3PARAM.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -20,7 +20,7 @@ Net::DNS::RR::NSEC3PARAM - DNS NSEC3PARAM resource record
 use integer;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -29,7 +29,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless $self->{algorithm};
@@ -38,7 +38,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{algorithm};
@@ -46,7 +46,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->algorithm(shift);
@@ -61,7 +61,7 @@ sub algorithm {
 	my $self = shift;
 
 	$self->{algorithm} = 0 + shift if scalar @_;
-	return $self->{algorithm} || 0;
+	$self->{algorithm} || 0;
 }
 
 
@@ -69,7 +69,7 @@ sub flags {
 	my $self = shift;
 
 	$self->{flags} = 0 + shift if scalar @_;
-	return $self->{flags} || 0;
+	$self->{flags} || 0;
 }
 
 
@@ -77,7 +77,7 @@ sub iterations {
 	my $self = shift;
 
 	$self->{iterations} = 0 + shift if scalar @_;
-	return $self->{iterations} || 0;
+	$self->{iterations} || 0;
 }
 
 
@@ -99,7 +99,7 @@ sub saltbin {
 
 ########################################
 
-sub hashalgo { &algorithm; }		## historical
+sub hashalgo { &algorithm; }					# uncoverable pod
 
 
 1;
