@@ -1,10 +1,10 @@
 package Net::DNS::RR::OPENPGPKEY;
 
 #
-# $Id: OPENPGPKEY.pm 1341 2015-05-10 15:31:26Z willem $
+# $Id: OPENPGPKEY.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1341 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -22,7 +22,7 @@ use integer;
 use MIME::Base64;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -31,21 +31,21 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	pack 'a*', $self->keysbin || '';
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my @base64 = split /\s+/, encode_base64( $self->keysbin );
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->keys(@_);
@@ -56,7 +56,7 @@ sub keys {
 	my $self = shift;
 
 	$self->keysbin( MIME::Base64::decode( join "", @_ ) ) if scalar @_;
-	return MIME::Base64::encode( $self->keysbin(), "" ) if defined wantarray;
+	MIME::Base64::encode( $self->keysbin(), "" ) if defined wantarray;
 }
 
 
