@@ -1,10 +1,10 @@
 package Net::DNS::RR::OPT;
 
 #
-# $Id: OPT.pm 1365 2015-06-26 08:46:01Z willem $
+# $Id: OPT.pm 1381 2015-08-25 07:36:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1365 $)[1];
+$VERSION = (qw$LastChangedRevision: 1381 $)[1];
 
 
 use strict;
@@ -27,7 +27,7 @@ use constant CLASS_TTL_RDLENGTH => length pack 'n N n', (0) x 3;
 use constant OPT => typebyname qw(OPT);
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -47,7 +47,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	my $rdata = '';
@@ -62,7 +62,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 sub encode {				## overide RR method
 	my $self = shift;
 
-	my $data = $self->encode_rdata;
+	my $data = $self->_encode_rdata;
 	my $size = $self->size;
 	my @xttl = ( $self->rcode >> 4, $self->version, $self->flags );
 	pack 'C n n C2n n a*', 0, OPT, $size, @xttl, length($data), $data;
@@ -106,13 +106,15 @@ sub class {				## overide RR method
 sub ttl {				## overide RR method
 	my $self = shift;
 	carp qq[Usage: OPT has no "ttl" attribute, please use "flags()" or "rcode()"] unless $ttl++;
-	@{$self}{qw(rcode flags)} = unpack 'Cxn', pack 'N', shift if scalar @_;
-	pack 'C2n', $self->rcode, $self->version, $self->flags;
+	my @rcode = map unpack( 'C',   pack 'N', $_ ), @_;
+	my @flags = map unpack( 'x2n', pack 'N', $_ ), @_;
+	pack 'C2n', $self->rcode(@rcode), $self->version, $self->flags(@flags);
 }
 
 
 sub version {
-	shift->{version} || 0;
+	my $version = shift->{version};
+	return defined($version) ? $version : 0;
 }
 
 
@@ -163,10 +165,10 @@ sub option {
 }
 
 
-sub defined {
+sub _specified {
 	my $self = shift;
-	my @defd = grep $self->{$_}, qw(size flags rcode option);
-	return scalar @defd;
+	my @spec = grep $self->{$_}, qw(size flags rcode option);
+	return scalar @spec;
 }
 
 
@@ -236,7 +238,7 @@ header.
 
 16 bit field containing EDNS extended header flags.
 
-=head2 Options
+=head2 options, option
 
 	@option = $packet->edns->options;
 
