@@ -1,10 +1,10 @@
 package Net::DNS::RR::SRV;
 
 #
-# $Id: SRV.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: SRV.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -22,7 +22,7 @@ use integer;
 use Net::DNS::DomainName;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset, @opaque ) = @_;
 
@@ -32,7 +32,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 	my ( $offset, @opaque ) = @_;
 
@@ -42,7 +42,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{target};
@@ -50,7 +50,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	foreach my $attr (qw(priority weight port target)) {
@@ -63,7 +63,7 @@ sub priority {
 	my $self = shift;
 
 	$self->{priority} = 0 + shift if scalar @_;
-	return $self->{priority} || 0;
+	$self->{priority} || 0;
 }
 
 
@@ -71,7 +71,7 @@ sub weight {
 	my $self = shift;
 
 	$self->{weight} = 0 + shift if scalar @_;
-	return $self->{weight} || 0;
+	$self->{weight} || 0;
 }
 
 
@@ -79,7 +79,7 @@ sub port {
 	my $self = shift;
 
 	$self->{port} = 0 + shift if scalar @_;
-	return $self->{port} || 0;
+	$self->{port} || 0;
 }
 
 
@@ -91,16 +91,16 @@ sub target {
 }
 
 
-__PACKAGE__->set_rrsort_func(
-	'priority',
-	sub {
-		my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
-		$a->{priority} <=> $b->{priority}
-				|| $b->{weight} <=> $a->{weight};
-	} );
+# order RRs by numerically increasing priority, decreasing weight
+my $function = sub {
+	my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
+	$a->{priority} <=> $b->{priority}
+			|| $b->{weight} <=> $a->{weight};
+};
 
+__PACKAGE__->set_rrsort_func( 'priority', $function );
 
-__PACKAGE__->set_rrsort_func( 'default_sort', __PACKAGE__->get_rrsort_func('priority') );
+__PACKAGE__->set_rrsort_func( 'default_sort', $function );
 
 
 1;
